@@ -22,6 +22,12 @@ class CheckFuncSpacing(Rule):
         """
         Function return type and function name must be separated by a tab
         """
+        i = 0
+        while i < context.fname_pos:
+            if context.check_token(i, "IDENTIFIER") is True and context.peek_token(i).value == "__attribute__":
+                context.new_error("ATTR_EOL", context.peek_token(i))
+                break
+            i += 1
         i = context.fname_pos - 1
         while context.check_token(i, ["MULT", "BWISE_AND", "LPARENTHESIS"]) is True:
             i -= 1
